Class: ConsoleTable::ConsoleTableClass
- Inherits:
-
Object
- Object
- ConsoleTable::ConsoleTableClass
- Defined in:
- lib/console_table.rb
Instance Attribute Summary collapse
-
#footer ⇒ Object
readonly
Add strings to the footer array to have them formatted when the table closes.
Instance Method Summary collapse
-
#<<(options) ⇒ Object
Add rows to the table.
Instance Attribute Details
#footer ⇒ Object (readonly)
Add strings to the footer array to have them formatted when the table closes
22 23 24 |
# File 'lib/console_table.rb', line 22 def @footer end |
Instance Method Details
#<<(options) ⇒ Object
Add rows to the table. Prints immediately, consult documentation for examples
25 26 27 |
# File 'lib/console_table.rb', line 25 def <<() print() end |